package org.rcisoft.business.cmsActivity.service.impl;

import cn.hutool.core.util.ObjectUtil;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import lombok.extern.slf4j.Slf4j;
import org.rcisoft.business.cmsActivity.dao.CmsActivityRepository;
import org.rcisoft.business.cmsActivity.entity.CmsActivity;
import org.rcisoft.business.cmsActivity.service.CmsActivityService;
import org.rcisoft.common.component.Global;
import org.rcisoft.core.exception.CyServiceException;
import org.rcisoft.core.model.CyPageInfo;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.util.CyUserUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Isolation;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;

/**
 * @author cy
 * @date 2024年3月25日 下午1:42:40
 */
@Service
@Transactional(readOnly = true, propagation = Propagation.NOT_SUPPORTED)
@Slf4j
public class CmsActivityServiceImpl extends ServiceImpl<CmsActivityRepository, CmsActivity> implements CmsActivityService {

    @Autowired
    private Global global;


    /**
     * 保存 活动
     *
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel persist(CmsActivity cmsActivity) {
        //增加操作
        cmsActivity.setDelFlag("0");
        //当图片字段没有时增加默认1
        if (ObjectUtil.isNull(cmsActivity.getPictureId())) {
            cmsActivity.setPictureId(global.getDEFAULT_NEWS_LOCATION());
        }
        CmsActivity check = baseMapper.checkWeight(cmsActivity.getWeight());
        if (ObjectUtil.isNotNull(check)) {
            throw new CyServiceException(500, "权重已存在");
        } else {
            int line = baseMapper.insert(cmsActivity);
            log.debug(CyUserUtil.getAuthenUsername() + "新增了ID为" +
                    cmsActivity.getBusinessId() + "的活动信息");
            return new CyPersistModel(line);
        }
    }

    /**
     * 删除 活动
     *
     * @param cmsActivity
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel remove(CmsActivity cmsActivity) {
        int line = baseMapper.deleteCmsActivity(cmsActivity.getBusinessId());
        log.debug(CyUserUtil.getAuthenUsername() + "删除了ID为" +
                cmsActivity.getBusinessId() + "的活动信息");
        return new CyPersistModel(line);
    }

    /**
     * 修改 活动
     *
     * @param cmsActivity
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel merge(CmsActivity cmsActivity) {
        //修改文本中的#image
        String details = cmsActivity.getDetails().replace("#image", "data:image");
        cmsActivity.setDetails(details);
        CmsActivity check = baseMapper.checkWeight(cmsActivity.getWeight());
        if (ObjectUtil.isNotNull(check) && !check.getBusinessId().equals(cmsActivity.getBusinessId())) {
            throw new CyServiceException(500, "权重已存在");
        } else {
            int line = baseMapper.updateById(cmsActivity);
            log.debug(CyUserUtil.getAuthenUsername() + "修改了ID为" + cmsActivity.getBusinessId() + "的活动信息");
            return new CyPersistModel(line);
        }
    }

    /**
     * 根据id查询 活动
     *
     * @param id
     * @return
     */
    @Override
    public CmsActivity findById(Integer id) {
        CmsActivity cmsActivity = baseMapper.selectById(id);
        if (cmsActivity.getPath() != null) {
            cmsActivity.setPath(global.getBase_Discovery() + cmsActivity.getPath());
        }
        return cmsActivity;
    }

    /**
     * 分页查询 活动
     *
     * @param cmsActivity
     * @return
     */
    @Override
    public IPage<CmsActivity> findAllByPagination(CyPageInfo<CmsActivity> paginationUtility,
                                                  CmsActivity cmsActivity) {
        IPage<CmsActivity> cmsActivityIPage = baseMapper.queryCmsActivityPaged(paginationUtility, cmsActivity);
        List<CmsActivity> newsInformation = cmsActivityIPage.getRecords();
        for (CmsActivity news : newsInformation) {
            if (news.getPath() != null) {
                news.setPath(global.getBase_Discovery() + news.getPath());
            }
        }
        cmsActivityIPage.setRecords(newsInformation);
        return cmsActivityIPage;

    }

    /**
     * 查询list 活动
     *
     * @param cmsActivity
     * @return
     */
    @Override
    public List<CmsActivity> findAll(CmsActivity cmsActivity) {
        return baseMapper.queryCmsActivity(cmsActivity);

    }

    /**
     * 导出活动
     *
     * @return
     */
    @Override
    public List<CmsActivity> export(CmsActivity cmsActivity) {
        List<CmsActivity> cmsActivityList = baseMapper.queryCmsActivity(cmsActivity);
        return cmsActivityList;
    }

    @Override
    public CyPersistModel updateStatus(CmsActivity cmsActivity) {
        int line = baseMapper.updateStatus(cmsActivity);
        log.debug(CyUserUtil.getAuthenUsername() + "修改了ID为" + cmsActivity.getBusinessId() + "的活动信息状态");
        return new CyPersistModel(line);
    }

}
